@@ -20,7 +20,8 @@ from lesscode.db.connection_info import ConnectionInfo
 from lesscode.db.es.es_pool import EsPool
 from lesscode.db.es.es_request import EsRequest
 from lesscode.db.page import Page
-from lesscode.utils.EsUtil import format_es_param_result
+from lesscode.utils.EsUtil import format_es_param_result, correction_query, es_mapping2dict
+from lesscode.utils.common import dict2single_dict
 from lesscode.utils.encryption_algorithm import AES
 
 
@@ -462,11 +463,20 @@ class EsHelper:
     def sync_es_search(self, route_key, body):
         path = f"/{route_key}/_search"
         url = self.pool.format_url(path)
+        self.correction_body(route_key, body)
         res = self.pool.format_es_post(url, body=body)
         if "error" in res:
             raise Exception(f"res={res}")
         return res
 
+    def correction_body(self, route_key, body):
+        try:
+            es_mapping_res = self.sync_es_mapping(route_key)
+            es_mapping = es_mapping_res.get(route_key, {}).get("mappings", {})
+            self.correction_param(body, es_mapping)
+        except Exception as e:
+            traceback.format_exc()
+
     def sync_es_search_format_hits(self, route_key, body):
         res = self.sync_es_search(route_key, body)
         hits = res.get("hits", {})
@@ -494,6 +504,7 @@ class EsHelper:
     def sync_es_scan(self, route_key, body, scroll="5m"):
         path = f"/{route_key}/_search?scroll={scroll}"
         url = self.pool.format_url(path)
+        self.correction_body(route_key, body)
         res = self.pool.format_es_post(url, body=body)
         data_list = []
         if "error" in res:
