@@ -62,7 +62,7 @@ class Ks3Oss:
         if bucket_name:
             self.instance = self.client.get_bucket(bucket_name)
         if self.instance.get_key(key, **kwargs):
-            return f'{protocol}://{bucket_name}.{region}.{domain}/{key}'
+            return f'{protocol}://{self.instance.name}.{region}.{domain}/{key}'
         else:
             return None
 
